# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NetworkResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bond_reward_rune': 'str',
        'total_bond_units': 'str',
        'available_pools_rune': 'str',
        'vaults_liquidity_rune': 'str',
        'effective_security_bond': 'str',
        'total_reserve': 'str',
        'vaults_migrating': 'bool',
        'gas_spent_rune': 'str',
        'gas_withheld_rune': 'str',
        'outbound_fee_multiplier': 'str',
        'native_outbound_fee_rune': 'str',
        'native_tx_fee_rune': 'str',
        'tns_register_fee_rune': 'str',
        'tns_fee_per_block_rune': 'str',
        'rune_price_in_tor': 'str',
        'tor_price_in_rune': 'str'
    }

    attribute_map = {
        'bond_reward_rune': 'bond_reward_rune',
        'total_bond_units': 'total_bond_units',
        'available_pools_rune': 'available_pools_rune',
        'vaults_liquidity_rune': 'vaults_liquidity_rune',
        'effective_security_bond': 'effective_security_bond',
        'total_reserve': 'total_reserve',
        'vaults_migrating': 'vaults_migrating',
        'gas_spent_rune': 'gas_spent_rune',
        'gas_withheld_rune': 'gas_withheld_rune',
        'outbound_fee_multiplier': 'outbound_fee_multiplier',
        'native_outbound_fee_rune': 'native_outbound_fee_rune',
        'native_tx_fee_rune': 'native_tx_fee_rune',
        'tns_register_fee_rune': 'tns_register_fee_rune',
        'tns_fee_per_block_rune': 'tns_fee_per_block_rune',
        'rune_price_in_tor': 'rune_price_in_tor',
        'tor_price_in_rune': 'tor_price_in_rune'
    }

    def __init__(self, bond_reward_rune=None, total_bond_units=None, available_pools_rune=None, vaults_liquidity_rune=None, effective_security_bond=None, total_reserve=None, vaults_migrating=None, gas_spent_rune=None, gas_withheld_rune=None, outbound_fee_multiplier=None, native_outbound_fee_rune=None, native_tx_fee_rune=None, tns_register_fee_rune=None, tns_fee_per_block_rune=None, rune_price_in_tor=None, tor_price_in_rune=None):  # noqa: E501
        """NetworkResponse - a model defined in Swagger"""  # noqa: E501
        self._bond_reward_rune = None
        self._total_bond_units = None
        self._available_pools_rune = None
        self._vaults_liquidity_rune = None
        self._effective_security_bond = None
        self._total_reserve = None
        self._vaults_migrating = None
        self._gas_spent_rune = None
        self._gas_withheld_rune = None
        self._outbound_fee_multiplier = None
        self._native_outbound_fee_rune = None
        self._native_tx_fee_rune = None
        self._tns_register_fee_rune = None
        self._tns_fee_per_block_rune = None
        self._rune_price_in_tor = None
        self._tor_price_in_rune = None
        self.discriminator = None
        self.bond_reward_rune = bond_reward_rune
        self.total_bond_units = total_bond_units
        self.available_pools_rune = available_pools_rune
        self.vaults_liquidity_rune = vaults_liquidity_rune
        self.effective_security_bond = effective_security_bond
        self.total_reserve = total_reserve
        self.vaults_migrating = vaults_migrating
        self.gas_spent_rune = gas_spent_rune
        self.gas_withheld_rune = gas_withheld_rune
        if outbound_fee_multiplier is not None:
            self.outbound_fee_multiplier = outbound_fee_multiplier
        self.native_outbound_fee_rune = native_outbound_fee_rune
        self.native_tx_fee_rune = native_tx_fee_rune
        self.tns_register_fee_rune = tns_register_fee_rune
        self.tns_fee_per_block_rune = tns_fee_per_block_rune
        self.rune_price_in_tor = rune_price_in_tor
        self.tor_price_in_rune = tor_price_in_rune

    @property
    def bond_reward_rune(self):
        """Gets the bond_reward_rune of this NetworkResponse.  # noqa: E501

        total amount of RUNE awarded to node operators  # noqa: E501

        :return: The bond_reward_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._bond_reward_rune

    @bond_reward_rune.setter
    def bond_reward_rune(self, bond_reward_rune):
        """Sets the bond_reward_rune of this NetworkResponse.

        total amount of RUNE awarded to node operators  # noqa: E501

        :param bond_reward_rune: The bond_reward_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if bond_reward_rune is None:
            raise ValueError("Invalid value for `bond_reward_rune`, must not be `None`")  # noqa: E501

        self._bond_reward_rune = bond_reward_rune

    @property
    def total_bond_units(self):
        """Gets the total_bond_units of this NetworkResponse.  # noqa: E501

        total bonded RUNE  # noqa: E501

        :return: The total_bond_units of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._total_bond_units

    @total_bond_units.setter
    def total_bond_units(self, total_bond_units):
        """Sets the total_bond_units of this NetworkResponse.

        total bonded RUNE  # noqa: E501

        :param total_bond_units: The total_bond_units of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if total_bond_units is None:
            raise ValueError("Invalid value for `total_bond_units`, must not be `None`")  # noqa: E501

        self._total_bond_units = total_bond_units

    @property
    def available_pools_rune(self):
        """Gets the available_pools_rune of this NetworkResponse.  # noqa: E501

        RUNE in Available pools (equal in value to the Assets in those pools)  # noqa: E501

        :return: The available_pools_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._available_pools_rune

    @available_pools_rune.setter
    def available_pools_rune(self, available_pools_rune):
        """Sets the available_pools_rune of this NetworkResponse.

        RUNE in Available pools (equal in value to the Assets in those pools)  # noqa: E501

        :param available_pools_rune: The available_pools_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if available_pools_rune is None:
            raise ValueError("Invalid value for `available_pools_rune`, must not be `None`")  # noqa: E501

        self._available_pools_rune = available_pools_rune

    @property
    def vaults_liquidity_rune(self):
        """Gets the vaults_liquidity_rune of this NetworkResponse.  # noqa: E501

        RUNE value of Layer 1 Assets in vaults  # noqa: E501

        :return: The vaults_liquidity_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._vaults_liquidity_rune

    @vaults_liquidity_rune.setter
    def vaults_liquidity_rune(self, vaults_liquidity_rune):
        """Sets the vaults_liquidity_rune of this NetworkResponse.

        RUNE value of Layer 1 Assets in vaults  # noqa: E501

        :param vaults_liquidity_rune: The vaults_liquidity_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if vaults_liquidity_rune is None:
            raise ValueError("Invalid value for `vaults_liquidity_rune`, must not be `None`")  # noqa: E501

        self._vaults_liquidity_rune = vaults_liquidity_rune

    @property
    def effective_security_bond(self):
        """Gets the effective_security_bond of this NetworkResponse.  # noqa: E501

        effective security bond used to determine maximum pooled RUNE  # noqa: E501

        :return: The effective_security_bond of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._effective_security_bond

    @effective_security_bond.setter
    def effective_security_bond(self, effective_security_bond):
        """Sets the effective_security_bond of this NetworkResponse.

        effective security bond used to determine maximum pooled RUNE  # noqa: E501

        :param effective_security_bond: The effective_security_bond of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if effective_security_bond is None:
            raise ValueError("Invalid value for `effective_security_bond`, must not be `None`")  # noqa: E501

        self._effective_security_bond = effective_security_bond

    @property
    def total_reserve(self):
        """Gets the total_reserve of this NetworkResponse.  # noqa: E501

        total reserve RUNE  # noqa: E501

        :return: The total_reserve of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._total_reserve

    @total_reserve.setter
    def total_reserve(self, total_reserve):
        """Sets the total_reserve of this NetworkResponse.

        total reserve RUNE  # noqa: E501

        :param total_reserve: The total_reserve of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if total_reserve is None:
            raise ValueError("Invalid value for `total_reserve`, must not be `None`")  # noqa: E501

        self._total_reserve = total_reserve

    @property
    def vaults_migrating(self):
        """Gets the vaults_migrating of this NetworkResponse.  # noqa: E501

        Returns true if there exist RetiringVaults which have not finished migrating funds to new ActiveVaults  # noqa: E501

        :return: The vaults_migrating of this NetworkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._vaults_migrating

    @vaults_migrating.setter
    def vaults_migrating(self, vaults_migrating):
        """Sets the vaults_migrating of this NetworkResponse.

        Returns true if there exist RetiringVaults which have not finished migrating funds to new ActiveVaults  # noqa: E501

        :param vaults_migrating: The vaults_migrating of this NetworkResponse.  # noqa: E501
        :type: bool
        """
        if vaults_migrating is None:
            raise ValueError("Invalid value for `vaults_migrating`, must not be `None`")  # noqa: E501

        self._vaults_migrating = vaults_migrating

    @property
    def gas_spent_rune(self):
        """Gets the gas_spent_rune of this NetworkResponse.  # noqa: E501

        Sum of the gas the network has spent to send outbounds  # noqa: E501

        :return: The gas_spent_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._gas_spent_rune

    @gas_spent_rune.setter
    def gas_spent_rune(self, gas_spent_rune):
        """Sets the gas_spent_rune of this NetworkResponse.

        Sum of the gas the network has spent to send outbounds  # noqa: E501

        :param gas_spent_rune: The gas_spent_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if gas_spent_rune is None:
            raise ValueError("Invalid value for `gas_spent_rune`, must not be `None`")  # noqa: E501

        self._gas_spent_rune = gas_spent_rune

    @property
    def gas_withheld_rune(self):
        """Gets the gas_withheld_rune of this NetworkResponse.  # noqa: E501

        Sum of the gas withheld from users to cover outbound gas  # noqa: E501

        :return: The gas_withheld_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._gas_withheld_rune

    @gas_withheld_rune.setter
    def gas_withheld_rune(self, gas_withheld_rune):
        """Sets the gas_withheld_rune of this NetworkResponse.

        Sum of the gas withheld from users to cover outbound gas  # noqa: E501

        :param gas_withheld_rune: The gas_withheld_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if gas_withheld_rune is None:
            raise ValueError("Invalid value for `gas_withheld_rune`, must not be `None`")  # noqa: E501

        self._gas_withheld_rune = gas_withheld_rune

    @property
    def outbound_fee_multiplier(self):
        """Gets the outbound_fee_multiplier of this NetworkResponse.  # noqa: E501

        Current outbound fee multiplier, in basis points  # noqa: E501

        :return: The outbound_fee_multiplier of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._outbound_fee_multiplier

    @outbound_fee_multiplier.setter
    def outbound_fee_multiplier(self, outbound_fee_multiplier):
        """Sets the outbound_fee_multiplier of this NetworkResponse.

        Current outbound fee multiplier, in basis points  # noqa: E501

        :param outbound_fee_multiplier: The outbound_fee_multiplier of this NetworkResponse.  # noqa: E501
        :type: str
        """

        self._outbound_fee_multiplier = outbound_fee_multiplier

    @property
    def native_outbound_fee_rune(self):
        """Gets the native_outbound_fee_rune of this NetworkResponse.  # noqa: E501

        the outbound transaction fee in rune, converted from the NativeOutboundFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :return: The native_outbound_fee_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._native_outbound_fee_rune

    @native_outbound_fee_rune.setter
    def native_outbound_fee_rune(self, native_outbound_fee_rune):
        """Sets the native_outbound_fee_rune of this NetworkResponse.

        the outbound transaction fee in rune, converted from the NativeOutboundFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :param native_outbound_fee_rune: The native_outbound_fee_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if native_outbound_fee_rune is None:
            raise ValueError("Invalid value for `native_outbound_fee_rune`, must not be `None`")  # noqa: E501

        self._native_outbound_fee_rune = native_outbound_fee_rune

    @property
    def native_tx_fee_rune(self):
        """Gets the native_tx_fee_rune of this NetworkResponse.  # noqa: E501

        the native transaction fee in rune, converted from the NativeTransactionFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :return: The native_tx_fee_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._native_tx_fee_rune

    @native_tx_fee_rune.setter
    def native_tx_fee_rune(self, native_tx_fee_rune):
        """Sets the native_tx_fee_rune of this NetworkResponse.

        the native transaction fee in rune, converted from the NativeTransactionFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :param native_tx_fee_rune: The native_tx_fee_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if native_tx_fee_rune is None:
            raise ValueError("Invalid value for `native_tx_fee_rune`, must not be `None`")  # noqa: E501

        self._native_tx_fee_rune = native_tx_fee_rune

    @property
    def tns_register_fee_rune(self):
        """Gets the tns_register_fee_rune of this NetworkResponse.  # noqa: E501

        the thorname register fee in rune, converted from the TNSRegisterFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :return: The tns_register_fee_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._tns_register_fee_rune

    @tns_register_fee_rune.setter
    def tns_register_fee_rune(self, tns_register_fee_rune):
        """Sets the tns_register_fee_rune of this NetworkResponse.

        the thorname register fee in rune, converted from the TNSRegisterFeeUSD mimir (after USD fees are enabled)  # noqa: E501

        :param tns_register_fee_rune: The tns_register_fee_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if tns_register_fee_rune is None:
            raise ValueError("Invalid value for `tns_register_fee_rune`, must not be `None`")  # noqa: E501

        self._tns_register_fee_rune = tns_register_fee_rune

    @property
    def tns_fee_per_block_rune(self):
        """Gets the tns_fee_per_block_rune of this NetworkResponse.  # noqa: E501

        the thorname fee per block in rune, converted from the TNSFeePerBlockUSD mimir (after USD fees are enabled)  # noqa: E501

        :return: The tns_fee_per_block_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._tns_fee_per_block_rune

    @tns_fee_per_block_rune.setter
    def tns_fee_per_block_rune(self, tns_fee_per_block_rune):
        """Sets the tns_fee_per_block_rune of this NetworkResponse.

        the thorname fee per block in rune, converted from the TNSFeePerBlockUSD mimir (after USD fees are enabled)  # noqa: E501

        :param tns_fee_per_block_rune: The tns_fee_per_block_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if tns_fee_per_block_rune is None:
            raise ValueError("Invalid value for `tns_fee_per_block_rune`, must not be `None`")  # noqa: E501

        self._tns_fee_per_block_rune = tns_fee_per_block_rune

    @property
    def rune_price_in_tor(self):
        """Gets the rune_price_in_tor of this NetworkResponse.  # noqa: E501

        the rune price in tor  # noqa: E501

        :return: The rune_price_in_tor of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_in_tor

    @rune_price_in_tor.setter
    def rune_price_in_tor(self, rune_price_in_tor):
        """Sets the rune_price_in_tor of this NetworkResponse.

        the rune price in tor  # noqa: E501

        :param rune_price_in_tor: The rune_price_in_tor of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if rune_price_in_tor is None:
            raise ValueError("Invalid value for `rune_price_in_tor`, must not be `None`")  # noqa: E501

        self._rune_price_in_tor = rune_price_in_tor

    @property
    def tor_price_in_rune(self):
        """Gets the tor_price_in_rune of this NetworkResponse.  # noqa: E501

        the tor price in rune  # noqa: E501

        :return: The tor_price_in_rune of this NetworkResponse.  # noqa: E501
        :rtype: str
        """
        return self._tor_price_in_rune

    @tor_price_in_rune.setter
    def tor_price_in_rune(self, tor_price_in_rune):
        """Sets the tor_price_in_rune of this NetworkResponse.

        the tor price in rune  # noqa: E501

        :param tor_price_in_rune: The tor_price_in_rune of this NetworkResponse.  # noqa: E501
        :type: str
        """
        if tor_price_in_rune is None:
            raise ValueError("Invalid value for `tor_price_in_rune`, must not be `None`")  # noqa: E501

        self._tor_price_in_rune = tor_price_in_rune

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from xchainpy2_thornode.models.account import Account
from xchainpy2_thornode.models.account_response import AccountResponse
from xchainpy2_thornode.models.account_response_result import AccountResponseResult
from xchainpy2_thornode.models.amount import Amount
from xchainpy2_thornode.models.balances_response import BalancesResponse
from xchainpy2_thornode.models.ban_response import BanResponse
from xchainpy2_thornode.models.base_quote_response import BaseQuoteResponse
from xchainpy2_thornode.models.block_response import BlockResponse
from xchainpy2_thornode.models.block_response_header import BlockResponseHeader
from xchainpy2_thornode.models.block_response_header_version import BlockResponseHeaderVersion
from xchainpy2_thornode.models.block_response_id import BlockResponseId
from xchainpy2_thornode.models.block_response_id_parts import BlockResponseIdParts
from xchainpy2_thornode.models.block_tx import BlockTx
from xchainpy2_thornode.models.block_tx_result import BlockTxResult
from xchainpy2_thornode.models.borrower import Borrower
from xchainpy2_thornode.models.borrower_response import BorrowerResponse
from xchainpy2_thornode.models.borrowers_response import BorrowersResponse
from xchainpy2_thornode.models.chain_height import ChainHeight
from xchainpy2_thornode.models.coin import Coin
from xchainpy2_thornode.models.constants_response import ConstantsResponse
from xchainpy2_thornode.models.derived_pool import DerivedPool
from xchainpy2_thornode.models.derived_pool_response import DerivedPoolResponse
from xchainpy2_thornode.models.derived_pools_response import DerivedPoolsResponse
from xchainpy2_thornode.models.export_response import ExportResponse
from xchainpy2_thornode.models.inbound_address import InboundAddress
from xchainpy2_thornode.models.inbound_addresses_response import InboundAddressesResponse
from xchainpy2_thornode.models.inbound_confirmation_counted_stage import InboundConfirmationCountedStage
from xchainpy2_thornode.models.inbound_finalised_stage import InboundFinalisedStage
from xchainpy2_thornode.models.inbound_observed_stage import InboundObservedStage
from xchainpy2_thornode.models.inline_response200 import InlineResponse200
from xchainpy2_thornode.models.invariant_response import InvariantResponse
from xchainpy2_thornode.models.invariants_response import InvariantsResponse
from xchainpy2_thornode.models.keygen import Keygen
from xchainpy2_thornode.models.keygen_block import KeygenBlock
from xchainpy2_thornode.models.keygen_metric import KeygenMetric
from xchainpy2_thornode.models.keygen_metrics_response import KeygenMetricsResponse
from xchainpy2_thornode.models.keygen_response import KeygenResponse
from xchainpy2_thornode.models.keysign_info import KeysignInfo
from xchainpy2_thornode.models.keysign_metrics import KeysignMetrics
from xchainpy2_thornode.models.keysign_response import KeysignResponse
from xchainpy2_thornode.models.last_block import LastBlock
from xchainpy2_thornode.models.last_block_response import LastBlockResponse
from xchainpy2_thornode.models.liquidity_provider import LiquidityProvider
from xchainpy2_thornode.models.liquidity_provider_response import LiquidityProviderResponse
from xchainpy2_thornode.models.liquidity_provider_summary import LiquidityProviderSummary
from xchainpy2_thornode.models.liquidity_providers_response import LiquidityProvidersResponse
from xchainpy2_thornode.models.metrics_response import MetricsResponse
from xchainpy2_thornode.models.mimir_nodes_response import MimirNodesResponse
from xchainpy2_thornode.models.mimir_response import MimirResponse
from xchainpy2_thornode.models.mimir_vote import MimirVote
from xchainpy2_thornode.models.msg_swap import MsgSwap
from xchainpy2_thornode.models.network_response import NetworkResponse
from xchainpy2_thornode.models.node import Node
from xchainpy2_thornode.models.node_bond_provider import NodeBondProvider
from xchainpy2_thornode.models.node_bond_providers import NodeBondProviders
from xchainpy2_thornode.models.node_jail import NodeJail
from xchainpy2_thornode.models.node_keygen_metric import NodeKeygenMetric
from xchainpy2_thornode.models.node_preflight_status import NodePreflightStatus
from xchainpy2_thornode.models.node_pub_key_set import NodePubKeySet
from xchainpy2_thornode.models.node_response import NodeResponse
from xchainpy2_thornode.models.nodes_response import NodesResponse
from xchainpy2_thornode.models.observed_tx import ObservedTx
from xchainpy2_thornode.models.outbound_delay_stage import OutboundDelayStage
from xchainpy2_thornode.models.outbound_fee import OutboundFee
from xchainpy2_thornode.models.outbound_fees_response import OutboundFeesResponse
from xchainpy2_thornode.models.outbound_response import OutboundResponse
from xchainpy2_thornode.models.outbound_signed_stage import OutboundSignedStage
from xchainpy2_thornode.models.pol import POL
from xchainpy2_thornode.models.ping import Ping
from xchainpy2_thornode.models.planned_out_tx import PlannedOutTx
from xchainpy2_thornode.models.pool import Pool
from xchainpy2_thornode.models.pool_response import PoolResponse
from xchainpy2_thornode.models.pool_slip_response import PoolSlipResponse
from xchainpy2_thornode.models.pools_response import PoolsResponse
from xchainpy2_thornode.models.queue_response import QueueResponse
from xchainpy2_thornode.models.quote_fees import QuoteFees
from xchainpy2_thornode.models.quote_loan_close_response import QuoteLoanCloseResponse
from xchainpy2_thornode.models.quote_loan_open_response import QuoteLoanOpenResponse
from xchainpy2_thornode.models.quote_saver_deposit_response import QuoteSaverDepositResponse
from xchainpy2_thornode.models.quote_saver_withdraw_response import QuoteSaverWithdrawResponse
from xchainpy2_thornode.models.quote_swap_response import QuoteSwapResponse
from xchainpy2_thornode.models.rune_pool_response import RUNEPoolResponse
from xchainpy2_thornode.models.rune_pool_response_providers import RUNEPoolResponseProviders
from xchainpy2_thornode.models.rune_pool_response_reserve import RUNEPoolResponseReserve
from xchainpy2_thornode.models.rune_provider import RUNEProvider
from xchainpy2_thornode.models.rune_provider_response import RUNEProviderResponse
from xchainpy2_thornode.models.rune_providers_response import RUNEProvidersResponse
from xchainpy2_thornode.models.saver import Saver
from xchainpy2_thornode.models.saver_response import SaverResponse
from xchainpy2_thornode.models.savers_response import SaversResponse
from xchainpy2_thornode.models.scheduled_response import ScheduledResponse
from xchainpy2_thornode.models.secured_asset_response import SecuredAssetResponse
from xchainpy2_thornode.models.secured_assets_response import SecuredAssetsResponse
from xchainpy2_thornode.models.streaming_status import StreamingStatus
from xchainpy2_thornode.models.streaming_swap import StreamingSwap
from xchainpy2_thornode.models.streaming_swap_response import StreamingSwapResponse
from xchainpy2_thornode.models.streaming_swaps_response import StreamingSwapsResponse
from xchainpy2_thornode.models.swap_finalised_stage import SwapFinalisedStage
from xchainpy2_thornode.models.swap_queue_response import SwapQueueResponse
from xchainpy2_thornode.models.swap_status import SwapStatus
from xchainpy2_thornode.models.swapper_clout_response import SwapperCloutResponse
from xchainpy2_thornode.models.thorname import Thorname
from xchainpy2_thornode.models.thorname_alias import ThornameAlias
from xchainpy2_thornode.models.thorname_response import ThornameResponse
from xchainpy2_thornode.models.trade_account_response import TradeAccountResponse
from xchainpy2_thornode.models.trade_accounts_response import TradeAccountsResponse
from xchainpy2_thornode.models.trade_unit_response import TradeUnitResponse
from xchainpy2_thornode.models.trade_units_response import TradeUnitsResponse
from xchainpy2_thornode.models.tss_keysign_metric import TssKeysignMetric
from xchainpy2_thornode.models.tss_metric import TssMetric
from xchainpy2_thornode.models.tx import Tx
from xchainpy2_thornode.models.tx_details_response import TxDetailsResponse
from xchainpy2_thornode.models.tx_out_item import TxOutItem
from xchainpy2_thornode.models.tx_response import TxResponse
from xchainpy2_thornode.models.tx_signers_response import TxSignersResponse
from xchainpy2_thornode.models.tx_stages_response import TxStagesResponse
from xchainpy2_thornode.models.tx_status_response import TxStatusResponse
from xchainpy2_thornode.models.upgrade_proposal import UpgradeProposal
from xchainpy2_thornode.models.upgrade_proposal_response import UpgradeProposalResponse
from xchainpy2_thornode.models.upgrade_proposals_response import UpgradeProposalsResponse
from xchainpy2_thornode.models.upgrade_vote import UpgradeVote
from xchainpy2_thornode.models.upgrade_votes_response import UpgradeVotesResponse
from xchainpy2_thornode.models.vault import Vault
from xchainpy2_thornode.models.vault_address import VaultAddress
from xchainpy2_thornode.models.vault_info import VaultInfo
from xchainpy2_thornode.models.vault_pubkeys_response import VaultPubkeysResponse
from xchainpy2_thornode.models.vault_response import VaultResponse
from xchainpy2_thornode.models.vault_router import VaultRouter
from xchainpy2_thornode.models.vaults_response import VaultsResponse
from xchainpy2_thornode.models.version_response import VersionResponse
from xchainpy2_thornode.models.yggdrasil_vault import YggdrasilVault
from xchainpy2_thornode.models.yggdrasil_vaults_response import YggdrasilVaultsResponse



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TxStagesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inbound_observed': 'InboundObservedStage',
        'inbound_confirmation_counted': 'InboundConfirmationCountedStage',
        'inbound_finalised': 'InboundFinalisedStage',
        'swap_status': 'SwapStatus',
        'swap_finalised': 'SwapFinalisedStage',
        'outbound_delay': 'OutboundDelayStage',
        'outbound_signed': 'OutboundSignedStage'
    }

    attribute_map = {
        'inbound_observed': 'inbound_observed',
        'inbound_confirmation_counted': 'inbound_confirmation_counted',
        'inbound_finalised': 'inbound_finalised',
        'swap_status': 'swap_status',
        'swap_finalised': 'swap_finalised',
        'outbound_delay': 'outbound_delay',
        'outbound_signed': 'outbound_signed'
    }

    def __init__(self, inbound_observed=None, inbound_confirmation_counted=None, inbound_finalised=None, swap_status=None, swap_finalised=None, outbound_delay=None, outbound_signed=None):  # noqa: E501
        """TxStagesResponse - a model defined in Swagger"""  # noqa: E501
        self._inbound_observed = None
        self._inbound_confirmation_counted = None
        self._inbound_finalised = None
        self._swap_status = None
        self._swap_finalised = None
        self._outbound_delay = None
        self._outbound_signed = None
        self.discriminator = None
        self.inbound_observed = inbound_observed
        if inbound_confirmation_counted is not None:
            self.inbound_confirmation_counted = inbound_confirmation_counted
        if inbound_finalised is not None:
            self.inbound_finalised = inbound_finalised
        if swap_status is not None:
            self.swap_status = swap_status
        if swap_finalised is not None:
            self.swap_finalised = swap_finalised
        if outbound_delay is not None:
            self.outbound_delay = outbound_delay
        if outbound_signed is not None:
            self.outbound_signed = outbound_signed

    @property
    def inbound_observed(self):
        """Gets the inbound_observed of this TxStagesResponse.  # noqa: E501


        :return: The inbound_observed of this TxStagesResponse.  # noqa: E501
        :rtype: InboundObservedStage
        """
        return self._inbound_observed

    @inbound_observed.setter
    def inbound_observed(self, inbound_observed):
        """Sets the inbound_observed of this TxStagesResponse.


        :param inbound_observed: The inbound_observed of this TxStagesResponse.  # noqa: E501
        :type: InboundObservedStage
        """
        if inbound_observed is None:
            raise ValueError("Invalid value for `inbound_observed`, must not be `None`")  # noqa: E501

        self._inbound_observed = inbound_observed

    @property
    def inbound_confirmation_counted(self):
        """Gets the inbound_confirmation_counted of this TxStagesResponse.  # noqa: E501


        :return: The inbound_confirmation_counted of this TxStagesResponse.  # noqa: E501
        :rtype: InboundConfirmationCountedStage
        """
        return self._inbound_confirmation_counted

    @inbound_confirmation_counted.setter
    def inbound_confirmation_counted(self, inbound_confirmation_counted):
        """Sets the inbound_confirmation_counted of this TxStagesResponse.


        :param inbound_confirmation_counted: The inbound_confirmation_counted of this TxStagesResponse.  # noqa: E501
        :type: InboundConfirmationCountedStage
        """

        self._inbound_confirmation_counted = inbound_confirmation_counted

    @property
    def inbound_finalised(self):
        """Gets the inbound_finalised of this TxStagesResponse.  # noqa: E501


        :return: The inbound_finalised of this TxStagesResponse.  # noqa: E501
        :rtype: InboundFinalisedStage
        """
        return self._inbound_finalised

    @inbound_finalised.setter
    def inbound_finalised(self, inbound_finalised):
        """Sets the inbound_finalised of this TxStagesResponse.


        :param inbound_finalised: The inbound_finalised of this TxStagesResponse.  # noqa: E501
        :type: InboundFinalisedStage
        """

        self._inbound_finalised = inbound_finalised

    @property
    def swap_status(self):
        """Gets the swap_status of this TxStagesResponse.  # noqa: E501


        :return: The swap_status of this TxStagesResponse.  # noqa: E501
        :rtype: SwapStatus
        """
        return self._swap_status

    @swap_status.setter
    def swap_status(self, swap_status):
        """Sets the swap_status of this TxStagesResponse.


        :param swap_status: The swap_status of this TxStagesResponse.  # noqa: E501
        :type: SwapStatus
        """

        self._swap_status = swap_status

    @property
    def swap_finalised(self):
        """Gets the swap_finalised of this TxStagesResponse.  # noqa: E501


        :return: The swap_finalised of this TxStagesResponse.  # noqa: E501
        :rtype: SwapFinalisedStage
        """
        return self._swap_finalised

    @swap_finalised.setter
    def swap_finalised(self, swap_finalised):
        """Sets the swap_finalised of this TxStagesResponse.


        :param swap_finalised: The swap_finalised of this TxStagesResponse.  # noqa: E501
        :type: SwapFinalisedStage
        """

        self._swap_finalised = swap_finalised

    @property
    def outbound_delay(self):
        """Gets the outbound_delay of this TxStagesResponse.  # noqa: E501


        :return: The outbound_delay of this TxStagesResponse.  # noqa: E501
        :rtype: OutboundDelayStage
        """
        return self._outbound_delay

    @outbound_delay.setter
    def outbound_delay(self, outbound_delay):
        """Sets the outbound_delay of this TxStagesResponse.


        :param outbound_delay: The outbound_delay of this TxStagesResponse.  # noqa: E501
        :type: OutboundDelayStage
        """

        self._outbound_delay = outbound_delay

    @property
    def outbound_signed(self):
        """Gets the outbound_signed of this TxStagesResponse.  # noqa: E501


        :return: The outbound_signed of this TxStagesResponse.  # noqa: E501
        :rtype: OutboundSignedStage
        """
        return self._outbound_signed

    @outbound_signed.setter
    def outbound_signed(self, outbound_signed):
        """Sets the outbound_signed of this TxStagesResponse.


        :param outbound_signed: The outbound_signed of this TxStagesResponse.  # noqa: E501
        :type: OutboundSignedStage
        """

        self._outbound_signed = outbound_signed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TxStagesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TxStagesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Pool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'short_code': 'str',
        'status': 'str',
        'decimals': 'int',
        'pending_inbound_asset': 'str',
        'pending_inbound_rune': 'str',
        'balance_asset': 'str',
        'balance_rune': 'str',
        'asset_tor_price': 'str',
        'pool_units': 'str',
        'lp_units': 'str',
        'synth_units': 'str',
        'synth_supply': 'str',
        'savers_depth': 'str',
        'savers_units': 'str',
        'savers_fill_bps': 'str',
        'savers_capacity_remaining': 'str',
        'synth_mint_paused': 'bool',
        'synth_supply_remaining': 'str',
        'loan_collateral': 'str',
        'loan_collateral_remaining': 'str',
        'loan_cr': 'str',
        'derived_depth_bps': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'short_code': 'short_code',
        'status': 'status',
        'decimals': 'decimals',
        'pending_inbound_asset': 'pending_inbound_asset',
        'pending_inbound_rune': 'pending_inbound_rune',
        'balance_asset': 'balance_asset',
        'balance_rune': 'balance_rune',
        'asset_tor_price': 'asset_tor_price',
        'pool_units': 'pool_units',
        'lp_units': 'LP_units',
        'synth_units': 'synth_units',
        'synth_supply': 'synth_supply',
        'savers_depth': 'savers_depth',
        'savers_units': 'savers_units',
        'savers_fill_bps': 'savers_fill_bps',
        'savers_capacity_remaining': 'savers_capacity_remaining',
        'synth_mint_paused': 'synth_mint_paused',
        'synth_supply_remaining': 'synth_supply_remaining',
        'loan_collateral': 'loan_collateral',
        'loan_collateral_remaining': 'loan_collateral_remaining',
        'loan_cr': 'loan_cr',
        'derived_depth_bps': 'derived_depth_bps'
    }

    def __init__(self, asset=None, short_code=None, status=None, decimals=None, pending_inbound_asset=None, pending_inbound_rune=None, balance_asset=None, balance_rune=None, asset_tor_price=None, pool_units=None, lp_units=None, synth_units=None, synth_supply=None, savers_depth=None, savers_units=None, savers_fill_bps=None, savers_capacity_remaining=None, synth_mint_paused=None, synth_supply_remaining=None, loan_collateral=None, loan_collateral_remaining=None, loan_cr=None, derived_depth_bps=None):  # noqa: E501
        """Pool - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._short_code = None
        self._status = None
        self._decimals = None
        self._pending_inbound_asset = None
        self._pending_inbound_rune = None
        self._balance_asset = None
        self._balance_rune = None
        self._asset_tor_price = None
        self._pool_units = None
        self._lp_units = None
        self._synth_units = None
        self._synth_supply = None
        self._savers_depth = None
        self._savers_units = None
        self._savers_fill_bps = None
        self._savers_capacity_remaining = None
        self._synth_mint_paused = None
        self._synth_supply_remaining = None
        self._loan_collateral = None
        self._loan_collateral_remaining = None
        self._loan_cr = None
        self._derived_depth_bps = None
        self.discriminator = None
        self.asset = asset
        if short_code is not None:
            self.short_code = short_code
        self.status = status
        if decimals is not None:
            self.decimals = decimals
        self.pending_inbound_asset = pending_inbound_asset
        self.pending_inbound_rune = pending_inbound_rune
        self.balance_asset = balance_asset
        self.balance_rune = balance_rune
        self.asset_tor_price = asset_tor_price
        self.pool_units = pool_units
        self.lp_units = lp_units
        self.synth_units = synth_units
        self.synth_supply = synth_supply
        self.savers_depth = savers_depth
        self.savers_units = savers_units
        self.savers_fill_bps = savers_fill_bps
        self.savers_capacity_remaining = savers_capacity_remaining
        self.synth_mint_paused = synth_mint_paused
        self.synth_supply_remaining = synth_supply_remaining
        self.loan_collateral = loan_collateral
        self.loan_collateral_remaining = loan_collateral_remaining
        self.loan_cr = loan_cr
        self.derived_depth_bps = derived_depth_bps

    @property
    def asset(self):
        """Gets the asset of this Pool.  # noqa: E501


        :return: The asset of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this Pool.


        :param asset: The asset of this Pool.  # noqa: E501
        :type: str
        """
        if asset is None:
            raise ValueError("Invalid value for `asset`, must not be `None`")  # noqa: E501

        self._asset = asset

    @property
    def short_code(self):
        """Gets the short_code of this Pool.  # noqa: E501


        :return: The short_code of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._short_code

    @short_code.setter
    def short_code(self, short_code):
        """Sets the short_code of this Pool.


        :param short_code: The short_code of this Pool.  # noqa: E501
        :type: str
        """

        self._short_code = short_code

    @property
    def status(self):
        """Gets the status of this Pool.  # noqa: E501


        :return: The status of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Pool.


        :param status: The status of this Pool.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def decimals(self):
        """Gets the decimals of this Pool.  # noqa: E501


        :return: The decimals of this Pool.  # noqa: E501
        :rtype: int
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this Pool.


        :param decimals: The decimals of this Pool.  # noqa: E501
        :type: int
        """

        self._decimals = decimals

    @property
    def pending_inbound_asset(self):
        """Gets the pending_inbound_asset of this Pool.  # noqa: E501


        :return: The pending_inbound_asset of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._pending_inbound_asset

    @pending_inbound_asset.setter
    def pending_inbound_asset(self, pending_inbound_asset):
        """Sets the pending_inbound_asset of this Pool.


        :param pending_inbound_asset: The pending_inbound_asset of this Pool.  # noqa: E501
        :type: str
        """
        if pending_inbound_asset is None:
            raise ValueError("Invalid value for `pending_inbound_asset`, must not be `None`")  # noqa: E501

        self._pending_inbound_asset = pending_inbound_asset

    @property
    def pending_inbound_rune(self):
        """Gets the pending_inbound_rune of this Pool.  # noqa: E501


        :return: The pending_inbound_rune of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._pending_inbound_rune

    @pending_inbound_rune.setter
    def pending_inbound_rune(self, pending_inbound_rune):
        """Sets the pending_inbound_rune of this Pool.


        :param pending_inbound_rune: The pending_inbound_rune of this Pool.  # noqa: E501
        :type: str
        """
        if pending_inbound_rune is None:
            raise ValueError("Invalid value for `pending_inbound_rune`, must not be `None`")  # noqa: E501

        self._pending_inbound_rune = pending_inbound_rune

    @property
    def balance_asset(self):
        """Gets the balance_asset of this Pool.  # noqa: E501


        :return: The balance_asset of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._balance_asset

    @balance_asset.setter
    def balance_asset(self, balance_asset):
        """Sets the balance_asset of this Pool.


        :param balance_asset: The balance_asset of this Pool.  # noqa: E501
        :type: str
        """
        if balance_asset is None:
            raise ValueError("Invalid value for `balance_asset`, must not be `None`")  # noqa: E501

        self._balance_asset = balance_asset

    @property
    def balance_rune(self):
        """Gets the balance_rune of this Pool.  # noqa: E501


        :return: The balance_rune of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._balance_rune

    @balance_rune.setter
    def balance_rune(self, balance_rune):
        """Sets the balance_rune of this Pool.


        :param balance_rune: The balance_rune of this Pool.  # noqa: E501
        :type: str
        """
        if balance_rune is None:
            raise ValueError("Invalid value for `balance_rune`, must not be `None`")  # noqa: E501

        self._balance_rune = balance_rune

    @property
    def asset_tor_price(self):
        """Gets the asset_tor_price of this Pool.  # noqa: E501

        the USD (TOR) price of the asset in 1e8  # noqa: E501

        :return: The asset_tor_price of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._asset_tor_price

    @asset_tor_price.setter
    def asset_tor_price(self, asset_tor_price):
        """Sets the asset_tor_price of this Pool.

        the USD (TOR) price of the asset in 1e8  # noqa: E501

        :param asset_tor_price: The asset_tor_price of this Pool.  # noqa: E501
        :type: str
        """
        if asset_tor_price is None:
            raise ValueError("Invalid value for `asset_tor_price`, must not be `None`")  # noqa: E501

        self._asset_tor_price = asset_tor_price

    @property
    def pool_units(self):
        """Gets the pool_units of this Pool.  # noqa: E501

        the total pool units, this is the sum of LP and synth units  # noqa: E501

        :return: The pool_units of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._pool_units

    @pool_units.setter
    def pool_units(self, pool_units):
        """Sets the pool_units of this Pool.

        the total pool units, this is the sum of LP and synth units  # noqa: E501

        :param pool_units: The pool_units of this Pool.  # noqa: E501
        :type: str
        """
        if pool_units is None:
            raise ValueError("Invalid value for `pool_units`, must not be `None`")  # noqa: E501

        self._pool_units = pool_units

    @property
    def lp_units(self):
        """Gets the lp_units of this Pool.  # noqa: E501

        the total pool liquidity provider units  # noqa: E501

        :return: The lp_units of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._lp_units

    @lp_units.setter
    def lp_units(self, lp_units):
        """Sets the lp_units of this Pool.

        the total pool liquidity provider units  # noqa: E501

        :param lp_units: The lp_units of this Pool.  # noqa: E501
        :type: str
        """
        if lp_units is None:
            raise ValueError("Invalid value for `lp_units`, must not be `None`")  # noqa: E501

        self._lp_units = lp_units

    @property
    def synth_units(self):
        """Gets the synth_units of this Pool.  # noqa: E501

        the total synth units in the pool  # noqa: E501

        :return: The synth_units of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._synth_units

    @synth_units.setter
    def synth_units(self, synth_units):
        """Sets the synth_units of this Pool.

        the total synth units in the pool  # noqa: E501

        :param synth_units: The synth_units of this Pool.  # noqa: E501
        :type: str
        """
        if synth_units is None:
            raise ValueError("Invalid value for `synth_units`, must not be `None`")  # noqa: E501

        self._synth_units = synth_units

    @property
    def synth_supply(self):
        """Gets the synth_supply of this Pool.  # noqa: E501

        the total supply of synths for the asset  # noqa: E501

        :return: The synth_supply of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._synth_supply

    @synth_supply.setter
    def synth_supply(self, synth_supply):
        """Sets the synth_supply of this Pool.

        the total supply of synths for the asset  # noqa: E501

        :param synth_supply: The synth_supply of this Pool.  # noqa: E501
        :type: str
        """
        if synth_supply is None:
            raise ValueError("Invalid value for `synth_supply`, must not be `None`")  # noqa: E501

        self._synth_supply = synth_supply

    @property
    def savers_depth(self):
        """Gets the savers_depth of this Pool.  # noqa: E501

        the balance of L1 asset deposited into the Savers Vault  # noqa: E501

        :return: The savers_depth of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._savers_depth

    @savers_depth.setter
    def savers_depth(self, savers_depth):
        """Sets the savers_depth of this Pool.

        the balance of L1 asset deposited into the Savers Vault  # noqa: E501

        :param savers_depth: The savers_depth of this Pool.  # noqa: E501
        :type: str
        """
        if savers_depth is None:
            raise ValueError("Invalid value for `savers_depth`, must not be `None`")  # noqa: E501

        self._savers_depth = savers_depth

    @property
    def savers_units(self):
        """Gets the savers_units of this Pool.  # noqa: E501

        the number of units owned by Savers  # noqa: E501

        :return: The savers_units of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._savers_units

    @savers_units.setter
    def savers_units(self, savers_units):
        """Sets the savers_units of this Pool.

        the number of units owned by Savers  # noqa: E501

        :param savers_units: The savers_units of this Pool.  # noqa: E501
        :type: str
        """
        if savers_units is None:
            raise ValueError("Invalid value for `savers_units`, must not be `None`")  # noqa: E501

        self._savers_units = savers_units

    @property
    def savers_fill_bps(self):
        """Gets the savers_fill_bps of this Pool.  # noqa: E501

        the filled savers capacity in basis points, 4500/10000 = 45%  # noqa: E501

        :return: The savers_fill_bps of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._savers_fill_bps

    @savers_fill_bps.setter
    def savers_fill_bps(self, savers_fill_bps):
        """Sets the savers_fill_bps of this Pool.

        the filled savers capacity in basis points, 4500/10000 = 45%  # noqa: E501

        :param savers_fill_bps: The savers_fill_bps of this Pool.  # noqa: E501
        :type: str
        """
        if savers_fill_bps is None:
            raise ValueError("Invalid value for `savers_fill_bps`, must not be `None`")  # noqa: E501

        self._savers_fill_bps = savers_fill_bps

    @property
    def savers_capacity_remaining(self):
        """Gets the savers_capacity_remaining of this Pool.  # noqa: E501

        amount of remaining capacity in asset  # noqa: E501

        :return: The savers_capacity_remaining of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._savers_capacity_remaining

    @savers_capacity_remaining.setter
    def savers_capacity_remaining(self, savers_capacity_remaining):
        """Sets the savers_capacity_remaining of this Pool.

        amount of remaining capacity in asset  # noqa: E501

        :param savers_capacity_remaining: The savers_capacity_remaining of this Pool.  # noqa: E501
        :type: str
        """
        if savers_capacity_remaining is None:
            raise ValueError("Invalid value for `savers_capacity_remaining`, must not be `None`")  # noqa: E501

        self._savers_capacity_remaining = savers_capacity_remaining

    @property
    def synth_mint_paused(self):
        """Gets the synth_mint_paused of this Pool.  # noqa: E501

        whether additional synths cannot be minted  # noqa: E501

        :return: The synth_mint_paused of this Pool.  # noqa: E501
        :rtype: bool
        """
        return self._synth_mint_paused

    @synth_mint_paused.setter
    def synth_mint_paused(self, synth_mint_paused):
        """Sets the synth_mint_paused of this Pool.

        whether additional synths cannot be minted  # noqa: E501

        :param synth_mint_paused: The synth_mint_paused of this Pool.  # noqa: E501
        :type: bool
        """
        if synth_mint_paused is None:
            raise ValueError("Invalid value for `synth_mint_paused`, must not be `None`")  # noqa: E501

        self._synth_mint_paused = synth_mint_paused

    @property
    def synth_supply_remaining(self):
        """Gets the synth_supply_remaining of this Pool.  # noqa: E501

        the amount of synth supply remaining before the current max supply is reached  # noqa: E501

        :return: The synth_supply_remaining of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._synth_supply_remaining

    @synth_supply_remaining.setter
    def synth_supply_remaining(self, synth_supply_remaining):
        """Sets the synth_supply_remaining of this Pool.

        the amount of synth supply remaining before the current max supply is reached  # noqa: E501

        :param synth_supply_remaining: The synth_supply_remaining of this Pool.  # noqa: E501
        :type: str
        """
        if synth_supply_remaining is None:
            raise ValueError("Invalid value for `synth_supply_remaining`, must not be `None`")  # noqa: E501

        self._synth_supply_remaining = synth_supply_remaining

    @property
    def loan_collateral(self):
        """Gets the loan_collateral of this Pool.  # noqa: E501

        the amount of collateral collects for loans  # noqa: E501

        :return: The loan_collateral of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._loan_collateral

    @loan_collateral.setter
    def loan_collateral(self, loan_collateral):
        """Sets the loan_collateral of this Pool.

        the amount of collateral collects for loans  # noqa: E501

        :param loan_collateral: The loan_collateral of this Pool.  # noqa: E501
        :type: str
        """
        if loan_collateral is None:
            raise ValueError("Invalid value for `loan_collateral`, must not be `None`")  # noqa: E501

        self._loan_collateral = loan_collateral

    @property
    def loan_collateral_remaining(self):
        """Gets the loan_collateral_remaining of this Pool.  # noqa: E501

        the amount of remaining collateral collects for loans  # noqa: E501

        :return: The loan_collateral_remaining of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._loan_collateral_remaining

    @loan_collateral_remaining.setter
    def loan_collateral_remaining(self, loan_collateral_remaining):
        """Sets the loan_collateral_remaining of this Pool.

        the amount of remaining collateral collects for loans  # noqa: E501

        :param loan_collateral_remaining: The loan_collateral_remaining of this Pool.  # noqa: E501
        :type: str
        """
        if loan_collateral_remaining is None:
            raise ValueError("Invalid value for `loan_collateral_remaining`, must not be `None`")  # noqa: E501

        self._loan_collateral_remaining = loan_collateral_remaining

    @property
    def loan_cr(self):
        """Gets the loan_cr of this Pool.  # noqa: E501

        the current loan collateralization ratio  # noqa: E501

        :return: The loan_cr of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._loan_cr

    @loan_cr.setter
    def loan_cr(self, loan_cr):
        """Sets the loan_cr of this Pool.

        the current loan collateralization ratio  # noqa: E501

        :param loan_cr: The loan_cr of this Pool.  # noqa: E501
        :type: str
        """
        if loan_cr is None:
            raise ValueError("Invalid value for `loan_cr`, must not be `None`")  # noqa: E501

        self._loan_cr = loan_cr

    @property
    def derived_depth_bps(self):
        """Gets the derived_depth_bps of this Pool.  # noqa: E501

        the depth of the derived virtual pool relative to L1 pool (in basis points)  # noqa: E501

        :return: The derived_depth_bps of this Pool.  # noqa: E501
        :rtype: str
        """
        return self._derived_depth_bps

    @derived_depth_bps.setter
    def derived_depth_bps(self, derived_depth_bps):
        """Sets the derived_depth_bps of this Pool.

        the depth of the derived virtual pool relative to L1 pool (in basis points)  # noqa: E501

        :param derived_depth_bps: The derived_depth_bps of this Pool.  # noqa: E501
        :type: str
        """
        if derived_depth_bps is None:
            raise ValueError("Invalid value for `derived_depth_bps`, must not be `None`")  # noqa: E501

        self._derived_depth_bps = derived_depth_bps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thornode API

    Thornode REST API.  # noqa: E501

    OpenAPI spec version: 3.3.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'address': 'str',
        'pubkey': 'str',
        'sequence': 'int',
        'account_number': 'int'
    }

    attribute_map = {
        'type': 'type',
        'address': 'address',
        'pubkey': 'pubkey',
        'sequence': 'sequence',
        'account_number': 'account_number'
    }

    def __init__(self, type=None, address=None, pubkey=None, sequence=None, account_number=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._address = None
        self._pubkey = None
        self._sequence = None
        self._account_number = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if address is not None:
            self.address = address
        if pubkey is not None:
            self.pubkey = pubkey
        if sequence is not None:
            self.sequence = sequence
        if account_number is not None:
            self.account_number = account_number

    @property
    def type(self):
        """Gets the type of this Account.  # noqa: E501


        :return: The type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Account.


        :param type: The type of this Account.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def address(self):
        """Gets the address of this Account.  # noqa: E501


        :return: The address of this Account.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Account.


        :param address: The address of this Account.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def pubkey(self):
        """Gets the pubkey of this Account.  # noqa: E501


        :return: The pubkey of this Account.  # noqa: E501
        :rtype: str
        """
        return self._pubkey

    @pubkey.setter
    def pubkey(self, pubkey):
        """Sets the pubkey of this Account.


        :param pubkey: The pubkey of this Account.  # noqa: E501
        :type: str
        """

        self._pubkey = pubkey

    @property
    def sequence(self):
        """Gets the sequence of this Account.  # noqa: E501


        :return: The sequence of this Account.  # noqa: E501
        :rtype: int
        """
        return self._sequence

    @sequence.setter
    def sequence(self, sequence):
        """Sets the sequence of this Account.


        :param sequence: The sequence of this Account.  # noqa: E501
        :type: int
        """

        self._sequence = sequence

    @property
    def account_number(self):
        """Gets the account_number of this Account.  # noqa: E501


        :return: The account_number of this Account.  # noqa: E501
        :rtype: int
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this Account.


        :param account_number: The account_number of this Account.  # noqa: E501
        :type: int
        """

        self._account_number = account_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Account, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
